"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _jwtDecode = _interopRequireDefault(require("jwt-decode"));

var _constants = require("./lib/constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// created 25-mar-2019 by rich braun <docker@instantlinux.net>
var apiUrl = process.env.REACT_APP_API_URL;

function authHeaders() {
  var uid = sessionStorage.getItem('uid');
  var token = sessionStorage.getItem('token');
  return new Headers({
    Accept: 'application/json',
    Authorization: 'Basic ' + btoa(uid + ':' + token),
    'Content-Type': 'application/json'
  });
}

;

function oauth_redir(loc) {
  window.location = loc;
}

;
var authProvider = {
  login: function login(_ref) {
    var username = _ref.username,
        password = _ref.password,
        method = _ref.method,
        otp = _ref.otp;
    var headers;

    if (sessionStorage.getItem('auth') === 'pendingtotp') {
      headers = authHeaders();
    } else {
      headers = new Headers({
        'Content-Type': 'application/json'
      });
    }

    var request = new Request(apiUrl + '/auth', {
      method: 'POST',
      body: JSON.stringify({
        username: username,
        password: password,
        method: method,
        otp: otp
      }),
      credentials: 'include',
      headers: headers
    });
    return fetch(request).then(function (response) {
      if (response.status < 200 || response.status >= 303) {
        throw new Error(response.statusText);
      }

      return response.json();
    }).then(function (response) {
      return method === undefined || method === 'local' ? response : oauth_redir(response.location) // TODO see if this line can be removed
      .then(function (response) {
        return response.json();
      });
    }).then(function (_ref2) {
      var jwt_token = _ref2.jwt_token,
          resources = _ref2.resources,
          storage_id = _ref2.storage_id,
          settings_id = _ref2.settings_id;
      var decodedJwt = (0, _jwtDecode.default)(jwt_token);
      sessionStorage.setItem('uid', decodedJwt.sub);
      sessionStorage.setItem('token', decodedJwt.jti);
      sessionStorage.setItem('auth', decodedJwt.auth);
      sessionStorage.setItem('account_id', decodedJwt.acc);
      sessionStorage.setItem('resource_endpoints', JSON.stringify(resources));
      sessionStorage.setItem('settings_id', settings_id);
      sessionStorage.setItem('storage_id', storage_id); // console.log('auth: ' + JSON.stringify(decodedJwt));

      if (decodedJwt.auth.includes('pendingtotp')) {
        throw new Error('pendingtotp');
      } else if (decodedJwt.auth.includes('mfarequired')) {
        window.location = '/#/mfa';
        window.location.reload(true);
      }
    });
  },
  logout: function logout() {
    var request = new Request(apiUrl + '/logout', {
      method: 'GET',
      headers: authHeaders()
    });
    return fetch(request).then(function (response) {
      if (response.status < 200 || response.status >= 300) {
        throw new Error(response.statusText);
      }

      sessionStorage.removeItem('token');
      sessionStorage.removeItem('auth');
      sessionStorage.removeItem('account_id');
      sessionStorage.removeItem('uid');
      Promise.resolve();
      return '/welcome';
    });
  },
  getPermissions: function getPermissions() {
    var auth = sessionStorage.getItem('auth'); // console.log('getPermissions: ' + auth);

    if (auth || window.location.hash.match(_constants.skipAuthPaths)) {
      return Promise.resolve(auth || '');
    }

    return Promise.resolve('');
  },
  checkError: function checkError(error) {
    if (error.status === 401) {
      sessionStorage.removeItem('token');
      return Promise.reject();
    }

    return Promise.resolve();
  },
  checkAuth: function checkAuth() {
    if (sessionStorage.getItem('token') || window.location.hash.match(_constants.skipAuthPaths)) {
      return Promise.resolve();
    }

    return Promise.reject();
  }
};
var _default = authProvider;
exports.default = _default;