"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _reactAdmin = require("react-admin");

var _queryString = require("query-string");

var _constants = require("./lib/constants");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function urlPrefix(resource) {
  var fallbackUrl = process.env.REACT_APP_API_URL;
  var res = JSON.parse(sessionStorage.getItem('resource_endpoints'));
  return "".concat(res && resource in res ? res[resource] : fallbackUrl, "/").concat(resource);
}

function httpClient(url) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var uid = sessionStorage.getItem('uid');
  var token = sessionStorage.getItem('token');
  options.headers = new Headers({
    Accept: 'application/json',
    Authorization: 'Basic ' + btoa(uid + ':' + token)
  }); // console.log('httpClient ' + url + ', opt=' + JSON.stringify(options));

  return _reactAdmin.fetchUtils.fetchJson(url, _objectSpread(_objectSpread({}, options), {}, {
    credentials: 'include'
  }));
}

function cacheSeconds() {
  var seconds = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : _constants.apiCacheSec;
  var validUntil = new Date();
  validUntil.setTime(validUntil.getTime() + seconds * 1000);
  return validUntil;
}

var dataProvider = {
  getList: function getList(resource, params) {
    var query = {
      limit: params.pagination.perPage,
      offset: (params.pagination.page - 1) * params.pagination.perPage,
      status: ['active']
    };

    if (params.sort) {
      query.sort = params.sort.field + ':' + params.sort.order.toLowerCase();
    }

    if (params.filter.hasOwnProperty('q')) {
      params.filter.name = params.filter.q + '%';
      delete params.filter.q;
    } else if (params.filter.hasOwnProperty('name') && params.filter.name[0] !== '%') {
      params.filter.name = "%".concat(params.filter.name, "%");
    }

    if (Object.keys(params.filter).length > 0) {
      query.filter = JSON.stringify(params.filter);
    }

    return httpClient("".concat(urlPrefix(resource), "?").concat((0, _queryString.stringify)(query))).then(function (_ref) {
      var json = _ref.json;
      return {
        data: json.items,
        total: json.count,
        validUntil: cacheSeconds()
      };
    });
  },
  getOne: function getOne(resource, params) {
    return httpClient("".concat(urlPrefix(resource), "/").concat(params.id)).then(function (_ref2) {
      var json = _ref2.json;
      return {
        data: json,
        validUntil: cacheSeconds()
      };
    });
  },
  getMany: function getMany(resource, params) {
    var query = {
      filter: JSON.stringify({
        id: params.ids
      }),
      limit: params.ids.length
    };
    return httpClient("".concat(urlPrefix(resource), "?").concat((0, _queryString.stringify)(query))).then(function (_ref3) {
      var json = _ref3.json;
      return {
        data: json.items,
        total: json.count,
        validUntil: cacheSeconds()
      };
    });
  },
  getManyReference: function getManyReference(resource, params) {
    var _params$sort = params.sort,
        field = _params$sort.field,
        order = _params$sort.order;

    var filter = _objectSpread(_objectSpread({}, params.filter), {}, _defineProperty({}, params.target, params.id));

    if (params.target in params.filter) {
      // Not documented but filter-override appears to be required
      filter[params.target] = params.filter[params.target];
    }

    var query = {
      limit: params.pagination.perPage,
      offset: (params.pagination.page - 1) * params.pagination.perPage,
      sort: field + ':' + order.toLowerCase(),
      filter: JSON.stringify(filter)
    };
    return httpClient("".concat(urlPrefix(resource), "?").concat((0, _queryString.stringify)(query))).then(function (_ref4) {
      var json = _ref4.json;
      return {
        data: json.items,
        total: json.count,
        validUntil: cacheSeconds()
      };
    });
  },
  update: function update(resource, params) {
    _constants.excludeFields.forEach(function (val) {
      delete params.data[val];
    });

    if (resource === 'picture') {
      _constants.excludeExifFields.forEach(function (val) {
        delete params.data[val];
      });
    }

    var options = {
      method: 'PUT',
      body: JSON.stringify(params.data)
    };
    return httpClient("".concat(urlPrefix(resource), "/").concat(params.id), options).then(function (_ref5) {
      var json = _ref5.json;
      return {
        data: json
      };
    });
  },
  create: function create(resource, params) {
    return httpClient("".concat(urlPrefix(resource)), {
      method: 'POST',
      body: JSON.stringify(params.data)
    }).then(function (_ref6) {
      var json = _ref6.json;
      return {
        data: json
      };
    });
  },
  delete: function _delete(resource, params) {
    return httpClient("".concat(urlPrefix(resource), "/").concat(params.id), {
      method: 'DELETE'
    }).then(function (_ref7) {
      var json = _ref7.json;
      return {
        data: json
      };
    });
  },
  deleteMany: function deleteMany(resource, params) {
    return httpClient("".concat(urlPrefix(resource), "/").concat(params.ids.join()), {
      method: 'DELETE'
    }).then(function (_ref8) {
      var json = _ref8.json;
      return {
        data: json
      };
    });
  }
};
var _default = dataProvider;
exports.default = _default;