"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validateUsername = exports.validateURI = exports.validateSelected = exports.validateRequired96String = exports.validateRequired4096String = exports.validateRequired32String = exports.validateRequired255String = exports.validateRequired128String = exports.validatePositive = exports.validatePasswordOK = exports.validateNumMax = exports.validateNameShort = exports.validateNameGeneral = exports.validateName = exports.validateKeywordAlpha = exports.validateInteger = exports.validateEmail = exports.validateCountry = exports.validate64String = exports.validate32String = exports.validate255String = void 0;

var _reactAdmin = require("react-admin");

// Forms validation functions
// created 1-may-2019 by docker@instantlinux.net
var hasSelection = function hasSelection() {
  var message = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'ra.validation.required';
  return function (value) {
    return value == null ? message : undefined;
  };
};

var isNameOK = function isNameOK() {
  var message = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'Alphanumeric or _&.- characters';
  return function (value) {
    return value.match(/^[a-zA-Z0-9]+[a-zA-Z0-9 _&.-]*$/) ? undefined : message;
  };
};

var isKeywordAlphaNumeric = function isKeywordAlphaNumeric() {
  var message = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'Alphanumeric or _+@. characters';
  return function (value) {
    return value.match(/^[a-zA-Z]+[a-zA-Z0-9_+@.]*$/) ? undefined : message;
  };
};

var isKeywordAlphaNumericLC = function isKeywordAlphaNumericLC() {
  var message = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'Lowercase/numeric or _-. characters';
  return function (value) {
    return value.match(/^[a-z]+[a-z0-9_.-]*$/) ? undefined : message;
  };
};

var isCountryCode = function isCountryCode() {
  var message = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'Use uppercase';
  return function (value) {
    return value != null && value.match(/^[A-Z][A-Z]$/) ? undefined : message;
  };
};

var isURI = function isURI() {
  var message = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'URI format';
  return function (value) {
    return value && !value.match(/^https?:\/\/[a-zA-Z0-9+_=/.-]{1,56}$/) ? message : undefined;
  };
};

var hasComplexity = function hasComplexity() {
  var message = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'Must have upper, lower, and symbol chars';
  return function (value) {
    return value != null && !(value.match(/[A-Z]+/) && value.match(/[a-z]+/) && value.match(/[@~!#%^&*+=';,{}[|":<>?/\\\].]+/)) ? message : undefined;
  };
};

var isBlankorMin4Upto32 = function isBlankorMin4Upto32() {
  var message = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'Between 4 and 32 characters';
  return function (value) {
    return value && (value.length < 4 || value.length > 32) ? message : undefined;
  };
};

var isBlankorUpto64 = function isBlankorUpto64() {
  var message = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'Between 2 and 64 characters';
  return function (value) {
    return value && (value.length < 2 || value.length > 64) ? message : undefined;
  };
};

var isBlankorUpto255 = function isBlankorUpto255() {
  var message = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'Between 8 and 255 characters';
  return function (value) {
    return value && (value.length < 8 || value.length > 255) ? message : undefined;
  };
};

var validateCountry = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(2), (0, _reactAdmin.maxLength)(2), isCountryCode()];
exports.validateCountry = validateCountry;
var validateEmail = [(0, _reactAdmin.email)()];
exports.validateEmail = validateEmail;
var validateURI = [isURI()];
exports.validateURI = validateURI;
var validateInteger = [(0, _reactAdmin.number)(), (0, _reactAdmin.minValue)(0)];
exports.validateInteger = validateInteger;
var validateKeywordAlpha = [(0, _reactAdmin.required)(), isKeywordAlphaNumeric()];
exports.validateKeywordAlpha = validateKeywordAlpha;
var validateUsername = [(0, _reactAdmin.required)(), isBlankorMin4Upto32(), isKeywordAlphaNumericLC()];
exports.validateUsername = validateUsername;
var validateName = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(4), (0, _reactAdmin.maxLength)(255), isNameOK()];
exports.validateName = validateName;
var validateNameGeneral = [(0, _reactAdmin.required)(), isNameOK()];
exports.validateNameGeneral = validateNameGeneral;
var validateNameShort = [(0, _reactAdmin.required)(), isBlankorUpto64(), isNameOK()];
exports.validateNameShort = validateNameShort;
var validatePositive = [(0, _reactAdmin.number)(), (0, _reactAdmin.minValue)(1)];
exports.validatePositive = validatePositive;

var validateNumMax = function validateNumMax(max) {
  return [(0, _reactAdmin.number)(), (0, _reactAdmin.minValue)(1), (0, _reactAdmin.maxValue)(max)];
};

exports.validateNumMax = validateNumMax;
var validateSelected = [hasSelection()];
exports.validateSelected = validateSelected;
var validate32String = [isBlankorMin4Upto32()];
exports.validate32String = validate32String;
var validate64String = [isBlankorUpto64()];
exports.validate64String = validate64String;
var validate255String = [isBlankorUpto255()];
exports.validate255String = validate255String;
var validateRequired32String = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(2), (0, _reactAdmin.maxLength)(32)];
exports.validateRequired32String = validateRequired32String;
var validateRequired96String = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(2), (0, _reactAdmin.maxLength)(96)];
exports.validateRequired96String = validateRequired96String;
var validateRequired128String = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(4), (0, _reactAdmin.maxLength)(128)];
exports.validateRequired128String = validateRequired128String;
var validateRequired255String = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(8), (0, _reactAdmin.maxLength)(255)];
exports.validateRequired255String = validateRequired255String;
var validateRequired4096String = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(8), (0, _reactAdmin.maxLength)(4096)];
exports.validateRequired4096String = validateRequired4096String;
var validatePasswordOK = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(8), (0, _reactAdmin.maxLength)(64), hasComplexity()];
exports.validatePasswordOK = validatePasswordOK;