"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.albumShow = exports.albumList = exports.albumEdit = exports.albumCreate = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactAdmin = require("react-admin");

var _constants = require("../lib/constants");

var _raCustom = require("../lib/ra-custom");

var _validate = require("../lib/validate");

var _media = require("../lib/media");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var albumCreate = function albumCreate(props) {
  return /*#__PURE__*/_react.default.createElement(_reactAdmin.Create, props, /*#__PURE__*/_react.default.createElement(_reactAdmin.SimpleForm, null, /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "name",
    validate: _validate.validateNameShort
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.AutocompleteInput, {
    source: "privacy",
    choices: _constants.privacyChoices,
    defaultValue: "invitee"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.SelectArrayInput, {
    source: "sizes",
    label: "Thumbnail sizes - height",
    choices: [{
      id: 80,
      name: '80'
    }, {
      id: 100,
      name: '100'
    }, {
      id: 120,
      name: '120'
    }, {
      id: 160,
      name: '160'
    }, {
      id: 240,
      name: '240'
    }, {
      id: 600,
      name: '600'
    }, {
      id: 720,
      name: '720'
    }, {
      id: 800,
      name: '800'
    }, {
      id: 1024,
      name: '1024'
    }, {
      id: 1080,
      name: '1080'
    }, {
      id: 1280,
      name: '1280'
    }, {
      id: 2048,
      name: '2048'
    }],
    defaultValue: _constants.defaultThumbnailSizes,
    disabled: true
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    disabled: true,
    source: "status",
    defaultValue: "active"
  })));
};

exports.albumCreate = albumCreate;

var albumEdit = function albumEdit(props) {
  return /*#__PURE__*/_react.default.createElement(_reactAdmin.Edit, _extends({}, props, {
    title: /*#__PURE__*/_react.default.createElement(RecordName, null)
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.SimpleForm, null, /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "name",
    validate: _validate.validateNameShort
  }), /*#__PURE__*/_react.default.createElement(_media.MediaInput, {
    parent_id: props.id
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.AutocompleteInput, {
    source: "privacy",
    choices: _constants.privacyChoices
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.ReferenceArrayField, {
    source: "pictures",
    reference: "picture",
    fullWidth: true
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.Datagrid, {
    rowClick: "edit"
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.ImageField, {
    source: "thumbnail50x50",
    label: "Pic"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "name"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "caption",
    multiline: true,
    emptyText: " "
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.DeleteButton, null))), /*#__PURE__*/_react.default.createElement(_reactAdmin.SelectArrayInput, {
    source: "sizes",
    label: "Thumbnail sizes - height",
    choices: [{
      id: 80,
      name: '80'
    }, {
      id: 100,
      name: '100'
    }, {
      id: 120,
      name: '120'
    }, {
      id: 160,
      name: '160'
    }, {
      id: 240,
      name: '240'
    }, {
      id: 600,
      name: '600'
    }, {
      id: 720,
      name: '720'
    }, {
      id: 800,
      name: '800'
    }, {
      id: 1024,
      name: '1024'
    }, {
      id: 1080,
      name: '1080'
    }, {
      id: 1280,
      name: '1280'
    }, {
      id: 2048,
      name: '2048'
    }],
    disabled: true
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.ReferenceInput, {
    source: "category_id",
    reference: "category"
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.SelectInput, {
    optionText: "name"
  }))));
};

exports.albumEdit = albumEdit;

var albumShow = function albumShow(props) {
  return /*#__PURE__*/_react.default.createElement(_reactAdmin.Show, _extends({}, props, {
    title: /*#__PURE__*/_react.default.createElement(RecordName, null),
    actions: /*#__PURE__*/_react.default.createElement(_raCustom.TopbarActions, null)
  }), /*#__PURE__*/_react.default.createElement(_media.MediaGallery, null));
};

exports.albumShow = albumShow;

var albumList = function albumList(props) {
  return /*#__PURE__*/_react.default.createElement(_reactAdmin.List, props, /*#__PURE__*/_react.default.createElement(_reactAdmin.Datagrid, {
    rowClick: "show"
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.ReferenceField, {
    label: "Cover",
    source: "cover_id",
    link: false,
    reference: "picture"
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.ImageField, {
    source: "thumbnail50x50"
  })), /*#__PURE__*/_react.default.createElement(_reactAdmin.ChipField, {
    source: "name"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.ChipField, {
    source: "owner",
    sortable: false
  })));
};

exports.albumList = albumList;

var RecordName = function RecordName(_ref) {
  var record = _ref.record;
  return /*#__PURE__*/_react.default.createElement("span", null, record ? record.name : '');
};

var _default = albumCreate;
exports.default = _default;