"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.locationShow = exports.locationList = exports.locationEdit = exports.locationCreate = exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactAdmin = require("react-admin");

var _constants = require("../lib/constants");

var _mapbox = require("../lib/mapbox");

var _raCustom = require("../lib/ra-custom");

var _validate = require("../lib/validate");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var locationCreate = function locationCreate(props) {
  return /*#__PURE__*/_react.default.createElement(_reactAdmin.Create, props, /*#__PURE__*/_react.default.createElement(_reactAdmin.SimpleForm, {
    redirect: "show"
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "name",
    label: "Venue Name"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "address"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "city",
    validate: _validate.validateNameShort
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "state"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "postalcode"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "country",
    defaultValue: "US",
    validate: _validate.validateCountry
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "neighborhood"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.AutocompleteInput, {
    source: "privacy",
    choices: _constants.privacyChoices,
    defaultValue: "invitee"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.ReferenceInput, {
    source: "category_id",
    reference: "category"
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.SelectInput, {
    optionText: "name"
  })), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    disabled: true,
    source: "status",
    defaultValue: "active"
  })));
};

exports.locationCreate = locationCreate;

var locationEdit = function locationEdit(props) {
  return /*#__PURE__*/_react.default.createElement(_reactAdmin.Edit, _extends({}, props, {
    title: /*#__PURE__*/_react.default.createElement(MenuTitle, null)
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.SimpleForm, null, /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "name",
    label: "Venue Name"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "address"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "city"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "state"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "postalcode"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "country"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "neighborhood"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.AutocompleteInput, {
    source: "privacy",
    choices: _constants.privacyChoices
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.ReferenceInput, {
    source: "category_id",
    reference: "category"
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.SelectInput, {
    optionText: "name"
  })), /*#__PURE__*/_react.default.createElement(_reactAdmin.AutocompleteInput, {
    source: "status",
    choices: [{
      id: 'active',
      name: 'active'
    }, {
      id: 'disabled',
      name: 'disabled'
    }]
  })));
};

exports.locationEdit = locationEdit;

var Aside = function Aside(_ref) {
  var record = _ref.record;
  return /*#__PURE__*/_react.default.createElement(_mapbox.LocationMap, record);
};

var locationShow = function locationShow(props) {
  return /*#__PURE__*/_react.default.createElement(_reactAdmin.Show, _extends({}, props, {
    aside: /*#__PURE__*/_react.default.createElement(Aside, null),
    title: /*#__PURE__*/_react.default.createElement(MenuTitle, null),
    actions: /*#__PURE__*/_react.default.createElement(_raCustom.TopbarActions, null)
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.SimpleShowLayout, null, /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "name",
    label: "Venue Name",
    emptyText: " "
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "address",
    emptyText: " "
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "city",
    emptyText: " "
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "state",
    emptyText: " "
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "country",
    emptyText: " "
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "postalcode",
    emptyText: " "
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "neighborhood",
    emptyText: " "
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.ChipField, {
    source: "privacy"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.ChipField, {
    source: "category"
  })));
};

exports.locationShow = locationShow;

var locationList = function locationList(props) {
  return /*#__PURE__*/_react.default.createElement(_reactAdmin.List, _extends({}, props, {
    exporter: false,
    filters: /*#__PURE__*/_react.default.createElement(ListFilter, null),
    bulkActionButtons: false
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.Datagrid, {
    rowClick: "show"
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "name",
    label: "Venue Name",
    emptyText: " "
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "address",
    emptyText: " "
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "city",
    emptyText: " "
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "state",
    emptyText: " "
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "postalcode",
    emptyText: " "
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.ChipField, {
    source: "owner",
    sortable: false
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.ChipField, {
    source: "category",
    sortable: false
  })));
};

exports.locationList = locationList;

var MenuTitle = function MenuTitle(_ref2) {
  var record = _ref2.record;
  return /*#__PURE__*/_react.default.createElement("span", null, record.name ? record.name : record.address);
};

var ListFilter = function ListFilter(props) {
  return /*#__PURE__*/_react.default.createElement(_reactAdmin.Filter, props, /*#__PURE__*/_react.default.createElement(_reactAdmin.ReferenceInput, {
    source: "category_id",
    reference: "category"
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.SelectInput, {
    optionText: "name"
  })), /*#__PURE__*/_react.default.createElement(_reactAdmin.ReferenceInput, {
    source: "uid",
    reference: "person",
    label: "Owner"
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.AutocompleteInput, {
    optionText: "name"
  })), /*#__PURE__*/_react.default.createElement(_reactAdmin.SearchInput, {
    source: "name"
  }));
};

var _default = locationCreate;
exports.default = _default;