"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.messageShow = exports.messageList = exports.messageEdit = exports.messageCreate = exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactAdmin = require("react-admin");

var _raInputRichText = _interopRequireDefault(require("ra-input-rich-text"));

var _moment = _interopRequireDefault(require("moment"));

var _constants = require("../lib/constants");

var _raCustom = require("../lib/ra-custom");

var _validate = require("../lib/validate");

var _excluded = ["permissions"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function redirect(props) {
  var _ref = typeof props.location.state !== 'undefined' && props.location.state.record,
      list_id = _ref.list_id; // console.log('redirect list_id=' + list_id);


  return list_id ? "/list/".concat(list_id, "/show") : 'show';
}

var messageCreate = function messageCreate(_ref2) {
  var permissions = _ref2.permissions,
      props = _objectWithoutProperties(_ref2, _excluded);

  return (
    /*#__PURE__*/
    // TODO figure out how to create / display album
    _react.default.createElement(_reactAdmin.Create, props, /*#__PURE__*/_react.default.createElement(_reactAdmin.TabbedForm, {
      redirect: redirect(props)
    }, /*#__PURE__*/_react.default.createElement(_reactAdmin.FormTab, {
      label: "Message"
    }, /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
      source: "subject",
      validate: _validate.validateRequired128String
    }), /*#__PURE__*/_react.default.createElement(_raInputRichText.default, {
      source: "content",
      toolbar: _constants.toolbarOpts,
      validate: _validate.validateRequired4096String
    }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
      disabled: true,
      source: "privacy",
      defaultValue: "invitee"
    }))))
  );
};

exports.messageCreate = messageCreate;

var messageEdit = function messageEdit(props) {
  return /*#__PURE__*/_react.default.createElement(_reactAdmin.Edit, props, /*#__PURE__*/_react.default.createElement(_reactAdmin.TabbedForm, {
    redirect: redirect(props)
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.FormTab, {
    label: "Message"
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "subject",
    validate: _validate.validateRequired128String
  }), /*#__PURE__*/_react.default.createElement(_raInputRichText.default, {
    source: "content",
    toolbar: _constants.toolbarOpts,
    validate: _validate.validateRequired4096String
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.RadioButtonGroupInput, {
    source: "privacy",
    choices: _constants.privacyChoices
  }))));
};

exports.messageEdit = messageEdit;

var messageList = function messageList(props) {
  return /*#__PURE__*/_react.default.createElement(_reactAdmin.List, _extends({}, props, {
    exporter: false
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.Datagrid, {
    rowClick: "show",
    expand: /*#__PURE__*/_react.default.createElement(MessageView, null)
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.ReferenceField, {
    label: "Sender",
    source: "sender_id",
    reference: "person"
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "name"
  })), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextField, {
    source: "subject"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.DateField, {
    source: "created",
    label: "Date",
    showTime: true
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.ChipField, {
    source: "privacy"
  })));
};

exports.messageList = messageList;

var messageShow = function messageShow(props) {
  return /*#__PURE__*/_react.default.createElement(_reactAdmin.Show, _extends({}, props, {
    title: /*#__PURE__*/_react.default.createElement(_raCustom.MenuTitle, null),
    actions: /*#__PURE__*/_react.default.createElement(_raCustom.TopbarActions, null)
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.SimpleShowLayout, null, /*#__PURE__*/_react.default.createElement(_reactAdmin.ReferenceField, {
    label: "Sender",
    source: "sender_id",
    reference: "person"
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.ChipField, {
    source: "name"
  })), /*#__PURE__*/_react.default.createElement(_reactAdmin.FunctionField, {
    label: "Header",
    render: function render(record) {
      return "".concat(record.subject, " - ").concat((0, _moment.default)(record.created).fromNow());
    }
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.RichTextField, {
    source: "content"
  })));
};

exports.messageShow = messageShow;

var MessageView = function MessageView(_ref3) {
  var id = _ref3.id,
      record = _ref3.record,
      resource = _ref3.resource;
  return /*#__PURE__*/_react.default.createElement("div", {
    dangerouslySetInnerHTML: {
      __html: record.content
    }
  });
}; // const CreateAlbumButton = ({ ...props }) => {
//     const uid = sessionStorage.getItem('uid')
//     const album = (Math.random() + 1).toString(36).substring(2, 10)
//     return <Button component={Link} variant='contained'
//         to={{
//             pathname: '/album/create',
//             state: { record: { uid: uid, name: `msg-${album}` } },
//         }}>
//         Add
//     </Button>
// }


var _default = messageCreate;
exports.default = _default;